@@ -25,6 +25,7 @@ from lino import mixins
 from lino.api import dd, rt
 from lino.utils import ONE_DAY
 from etgen.html import E, tostring
+from lino.mixins import Registrable
 from lino.mixins.periods import Started, Ended
 from lino.mixins.periods import DateRangeObservable
 from lino.core.exceptions import ChangedAPI
@@ -754,12 +755,13 @@ class ReservationStates(Workflow):
     is_editable = models.BooleanField(_("Editable"), default=True)
 
 
-class Reservation(RecurrenceSet, EventGenerator, mixins.Registrable,
-                  UserAuthored):
+class Reservation(RecurrenceSet, EventGenerator, Registrable, UserAuthored):
 
     class Meta:
         abstract = True
 
+    workflow_state_field = 'state'
+
     room = dd.ForeignKey('cal.Room', blank=True, null=True)
     max_date = models.DateField(
         blank=True, null=True,
@@ -767,6 +769,8 @@ class Reservation(RecurrenceSet, EventGenerator, mixins.Registrable,
 
     @classmethod
     def on_analyze(cls, site):
+        if cls.workflow_state_field is None:
+            raise Exception("{} has no workflow_state_field".format(cls))
         super(Reservation, cls).on_analyze(site)
         ic = cls.workflow_state_field.choicelist
         k = 'auto_update_calendar'
