@@ -438,11 +438,6 @@ class Event(Component, Ended, Assignable, TypedPrintable, Mailable, Postable, Pu
         #         _("Show only entries having this {project}."),
         #         project=settings.SITE.project_model._meta.verbose_name)
 
-    @classmethod
-    def get_request_queryset(cls, ar, **filter):
-        qs = super(Event, cls).get_request_queryset(ar, **filter)
-        return cls.calendar_param_filter(qs, ar.param_values)
-
     @classmethod
     def get_simple_parameters(cls):
         for p in super(Event, cls).get_simple_parameters():
@@ -452,7 +447,12 @@ class Event(Component, Ended, Assignable, TypedPrintable, Mailable, Postable, Pu
         yield 'event_type'
 
     @classmethod
-    def calendar_param_filter(cls, qs, pv):
+    def get_request_queryset(cls, ar, **filter):
+        qs = super(Event, cls).get_request_queryset(ar, **filter)
+        # print("20200430 cal.Event.get_request_queryset", ar.param_values.project, qs.query)
+        # return cls.calendar_param_filter(qs, ar.param_values)
+        pv = ar.param_values
+
         # if pv.user:
         #     qs = qs.filter(user=pv.user)
         # if pv.assigned_to:
@@ -800,24 +800,26 @@ class Event(Component, Ended, Assignable, TypedPrintable, Mailable, Postable, Pu
     def get_event_summary(self, ar):
         # from django.utils.translation import ugettext as _
         s = self.summary
-        u = self.user
         if self.owner is not None:
             s = "{} {}".format(self.owner, s)
+
+        u = self.user
         if u is not None and u != ar.get_user():
             if self.access_class == AccessClasses.show_busy:
                 s = _("Busy")
             if self.summary_show_user:
                 s = "{} {}".format(u.initials or u.username, s)
-        if self.project is not None:
-            # s += " " + "{} {}".format(self.summary_project_template, self.project).strip()
-            s += " " + self.summary_project_template.format(project=self.project)
-        if self.state.button_text:
-            s = str(self.state.button_text) + " " + s
+
         # n = event.guest_set.all().count()
         # if n:
         #     s = ("[%d] " % n) + s
-        return s
 
+        if self.state.button_text:
+            yield str(self.state.button_text) + " "
+        yield s
+        if self.project is not None:
+            # s += " " + "{} {}".format(self.summary_project_template, self.project).strip()
+            yield " " + self.summary_project_template.format(project=self.project)
 
     def get_postable_recipients(self):
         """return or yield a list of Partners"""
@@ -1031,7 +1033,7 @@ class Guest(Printable):   # TODO: rename the model to "Presence"
     partner = dd.ForeignKey(dd.plugins.cal.partner_model)  # TODO: rename to "guest"
     role = dd.ForeignKey(
         'cal.GuestRole', verbose_name=_("Role"), blank=True, null=True)
-    state = GuestStates.field(default='invited')
+    state = GuestStates.field(default=dd.plugins.cal.default_guest_state)
     remark = models.CharField(_("Remark"), max_length=200, blank=True)
 
     allow_merge_action = False
@@ -1066,7 +1068,7 @@ class Guest(Printable):   # TODO: rename the model to "Presence"
         """
         if ar is None:
             return ''
-        return ar.obj2html(self.event, self.event.get_event_summary(ar))
+        return ar.obj2html(self.event, tuple(self.event.get_event_summary(ar)))
 
 
 def migrate_reminder(obj, reminder_date, reminder_text,
